# Console Conjugator
A commandline conjugator

Conjugate your verbs easily with the Console Conjugator! 

Have you ever had trouble conjugating your verbs? Maybe had problems with remembering present perfects or simple past forms of your verb? If not, then you are not human. If so, welcome to our commandline conjugator. As of now, we support only Deutschsprachen (German Language), but we're growing slowly and surely. Many of our colleagues use commandline more so than GUI applications or websites, so we wanted to make a solution for them. Very useful for AP Students.

-Govind Gnanakumar, Shynn Lawrence

Hab einen guten Tag!
